@@ -252,6 +252,7 @@ class CryoCon:
         self.channels = {channel: Channel(channel, self) for channel in channels}
         self.loops = {loop: Loop(loop, self) for loop in loops}
         self.group = None
+        self._lock = asyncio.Lock()
 
     def __getitem__(self, key):
         try:
@@ -295,10 +296,11 @@ class CryoCon:
 
     async def _async_io(self, func, request):
         self._log.debug("REQ: %r", request)
-        with self._guard_io() as wait_time:
-            if wait_time > 0:
-                await asyncio.sleep(wait_time)
-            reply = handle_reply(await func(request))
+        async with self._lock:
+            with self._guard_io() as wait_time:
+                if wait_time > 0:
+                    await asyncio.sleep(wait_time)
+                reply = handle_reply(await func(request))
         self._log.debug("REP: %r", reply)
         return reply
 
@@ -312,7 +314,7 @@ class CryoCon:
         return reply
 
     def _ask(self, cmd):
-        query = '?' in cmd
+        query = True
         raw_cmd = cmd.encode() + b'\n'
         io = self._conn.write_readline if query else self._conn.write
         handle = self._async_io if asyncio.iscoroutinefunction(io) else self._sync_io
